@@ -1,11 +1,15 @@
 from flask import request
 from flask.views import MethodView
 from json import dumps
+from jsonschema.exceptions import SchemaError
+from logging import getLogger
 
 from command_handler.request.exceptions import InvalidRequestException
 from command_handler.command.handler import registry
 from command_handler.request.validator import ValidatorFactory
 
+LOGGER = getLogger(__name__)
+
 
 class Invoker(MethodView):
     def __init__(self, **kwargs):
@@ -35,11 +39,16 @@ class Invoker(MethodView):
             command = data["command"]
 
             handler(payload, command)
+        except SchemaError:
+            code = 500
+            response["error"] = "Command payload schema error"
         except InvalidRequestException as e:
             code = e.code
             response["error"] = str(e)
-        except BaseException:
+        except BaseException as e:
             code = 500
             response["error"] = "Internal server error"
 
+            LOGGER.error(e)
+
         return dumps(response), code, headers
