@@ -178,6 +178,25 @@ class InvokerTest(TestCase):
 
         self.assertEqual(response[1], 500)
 
+    def testDispatchRequestLogsAnExceptionWhenHandlerIsRaisingException(self):
+        handler = Mock()
+        handler.side_effect = Exception
+
+        self.commandRegistry.add("foo.bar", handler, {})
+
+        with self.app.test_request_context(
+            content_type="application/json",
+            data=dumps({"command": "foo.bar", "payload": {}}),
+            method="POST",
+        ):
+            with patch("command_handler.views.LOGGER") as logger:
+                Invoker().dispatch_request()
+
+        self.assertTrue(logger.error.called)
+
+        args, kwargs = logger.error.call_args
+        self.assertIsInstance(args[0], Exception)
+
     def testDispatchRequestReturnsCode500AndInvalidSchemaMessageWhenCommandValidatorRaisesSchemaError(self):
         self.commandRegistry.add("foo.bar", lambda x: None, {})
         self.validatorFactory.create().test.side_effect = SchemaError("Foo")
